# Useful Links

| Service      | Enable API                                                                               | Overview                                                                 | Reference                                                                | Examples                                                                       |
|:-------------|:-----------------------------------------------------------------------------------------|:-------------------------------------------------------------------------|:-------------------------------------------------------------------------|:-------------------------------------------------------------------------------|
| **Calendar** | [Enable API](https://console.cloud.google.com/apis/library/calendar-json.googleapis.com) | [Overview](https://developers.google.com/calendar/api/guides/overview)   | [Reference](https://developers.google.com/calendar/api/v3/reference)     | [Examples](https://developers.google.com/calendar/api/guides/create-events)    |
| **Drive**    | [Enable API](https://console.cloud.google.com/apis/library/drive.googleapis.com)         | [Overview](https://developers.google.com/drive/api/guides/about-sdk)     | [Reference](https://developers.google.com/drive/api/reference/rest/v3)   | [Examples](https://developers.google.com/drive/api/guides/manage-uploads)      |
| **GMail**    | [Enable API](https://console.cloud.google.com/apis/library/gmail.googleapis.com)         | [Overview](https://developers.google.com/gmail/api/guides)               | [Reference](https://developers.google.com/gmail/api/reference/rest)      | [Examples](https://developers.google.com/gmail/api/guides/sending)             |
| **People**   | [Enable API](https://console.cloud.google.com/apis/library/people.googleapis.com)        | [Overview](https://developers.google.com/people)                         | [Reference](https://developers.google.com/people/api/rest)               | [Examples](https://developers.google.com/people/v1/profiles)                   |
| **Photos**   | [Enable API](https://console.cloud.google.com/apis/library/photoslibrary.googleapis.com) | [Overview](https://developers.google.com/photos/library/guides/overview) | [Reference](https://developers.google.com/photos/library/reference/rest) |                                                                                |
| **Sheets**   | [Enable API](https://console.cloud.google.com/apis/library/sheets.googleapis.com)        | [Overview](https://developers.google.com/sheets/api/guides/concepts)     | [Reference](https://developers.google.com/sheets/api/reference/rest)     | [Examples](https://developers.google.com/sheets/api/guides/batchupdate#python) |
| **YouTube**  | [Enable API](https://console.cloud.google.com/apis/library/youtube.googleapis.com)       | [Overview](https://developers.google.com/youtube/v3/getting-started)     | [Reference](https://developers.google.com/youtube/v3/docs)               |                                                                                |
